# Frequently Asked Questions

## How do I put files into nginx container?

1.  Retrieve the files in required folder structure.

2.  Copy them into nginx image.

    ```sh
    docker \
        cp ./ kemono-nginx:/storage
    ```

3.  Add required permissions to that folder.

    ```sh
    docker                  \
        exec kemono-nginx   \
        chown --recursive   \
        nginx /storage
    ```

## How Do I Install Python 3.12 on Ubuntu 22?
Through a PPA (Personal Package Archives).

1. Install required tooling and add the PPA:

   ```sh
   sudo apt install --assume-yes software-properties-common
   sudo add-apt-repository ppa:deadsnakes/ppa
   ```

2. Update local `apt` listing and install required python dependencies:

   ```sh
   sudo apt update
   sudo apt install \
     python3.12 \
     python3.12-dev \
     python3.12-distutils
   ```

3. Confirm python 3.12 is installed
   ```sh
   which python3.12
   ```

## How Do I Install Node.js 22.14?

### For Linux/macOS:

1. Install NVM:

   ```sh
   # Using curl
   curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.7/install.sh | bash
   
   # OR using wget
   wget -qO- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.7/install.sh | bash
   ```

2. Add NVM to your shell configuration:
   
   The installer should automatically add the necessary configuration to your shell profile 
   (`.bashrc`, `.zshrc`, etc.), but if it doesn't, add these lines manually:

   ```sh
   export NVM_DIR="$HOME/.nvm"
   [ -s "$NVM_DIR/nvm.sh" ] && \. "$NVM_DIR/nvm.sh" # This loads nvm
   [ -s "$NVM_DIR/bash_completion" ] && \. "$NVM_DIR/bash_completion" # This loads nvm bash_completion
   ```

3. Either restart your terminal or source your profile:

   ```sh
   # For bash
   source ~/.bashrc
   
   # For zsh
   source ~/.zshrc
   ```

4. Verify NVM installation:

   ```sh
   nvm --version
   ```

5. Install Node.js 22.14:

   ```sh
   nvm install 22.14
   ```

6. Set it as the default (optional):

   ```sh
   nvm alias default 22.14
   ```

7. Verify the installation:

   ```sh
   node --version  # Should output v22.14.0
   npm --version   # NPM is included with Node.js 10.9.2+
   ```

8. If you need to switch between Node.js versions:

   ```sh
   nvm ls
   
   nvm use 22.14
   
   nvm use default
   ```

### For Windows:

Windows users can install Node.js directly using the official installer:

1. Go to the Node.js downloads page:
   https://nodejs.org/en/download/current

2. Download the Windows installer for v22.14.0:
   - Look for `node-v22.14.X-x64.msi` (64-bit installer)
   - The "X" represents the patch version which may change

3. Run the downloaded MSI file and follow the installation wizard.

4. Verify the installation by opening Command Prompt or PowerShell and running:
   ```
   node --version
   npm --version
   ```

5. The installer includes npm, so no separate installation is needed. npm version should be 10.9.2 or newer.